@@ -7,12 +7,15 @@ from anasymod.base_config import BaseConfig
 
 class Plugin():
     def __init__(self, cfg_file, prj_root, build_root, name):
+        self.args = None
+
         self._cfg_file = cfg_file
         self._prj_root = prj_root
         self._build_root = build_root
-        self._srccfg_path = os.path.join(self._prj_root, r"source.config")
+        self._srccfg_path = os.path.join(self._prj_root, r"source.yaml")
         self._name = name
         self._defines = []
+        self.generator_sources = []
         self._verilog_sources = []
         """:type : List[VerilogSource]"""
 
@@ -27,6 +30,40 @@ class Plugin():
 
         self.include_statements = []
 
+
+    #### User Functions ####
+
+    def models(self):
+        """
+        Runs source code generator.
+        """
+        raise NotImplementedError()
+
+    def set_option(self, name, value=None):
+        func = getattr(self, name)
+        if callable(func):
+            if value is True or None:
+                func()
+            elif not value:
+                pass
+            else:
+                func(value)
+        else:
+            raise Exception(f'ERROR: Provided option:{name} is not supported for this generator.')
+
+    #### Utility Functions ####
+
+    def _add_source(self, source: Sources):
+        if isinstance(source, VerilogSource):
+            self._verilog_sources.append(source)
+        if isinstance(source, VerilogHeader):
+            self._verilog_headers.append(source)
+        if isinstance(source, VHDLSource):
+            self._vhdl_sources.append(source)
+
+    def _add_define(self, define: Define):
+        self._defines.append(define)
+
     def _dump_defines(self):
         return self._defines
 
@@ -51,17 +88,6 @@ class Plugin():
         """
         raise NotImplementedError()
 
-    def add_source(self, source: Sources):
-        if isinstance(source, VerilogSource):
-            self._verilog_sources.append(source)
-        if isinstance(source, VerilogHeader):
-            self._verilog_headers.append(source)
-        if isinstance(source, VHDLSource):
-            self._vhdl_sources.append(source)
-
-    def add_define(self, define: Define):
-        self._defines.append(define)
-
     def _parse_args(self):
         """
         Read command line arguments. This supports convenient usage from command shell e.g.:
@@ -69,11 +95,22 @@ class Plugin():
         """
         pass
 
-    #def _update_config(self, cfg, config_section):
-    #    return self.cfg.update_config(cfg=cfg, config_section=config_section)
+    def _return_args(self):
+        return self.args
 
-    #def _read_config(self, cfg_file, section, subsection=None):
-    #    return read_config(cfg_file=cfg_file, section=section, subsection=subsection)
+    def _set_generator_sources(self, generator_sources: list):
+        """
+        Set, which functional models shall be generated via the msdsl plugin. This works by setting the class instance
+        attribute self.generator_sources.
+
+        :param generator_sources: List of source objects specific to the generator
+        """
+
+        if any(isinstance(i, Sources) for i in generator_sources): # Make sure all elements in the list are of type Sources
+            [i.expand_paths() for i in generator_sources]
+            self.generator_sources = generator_sources
+        else:
+            raise Exception(f'ERROR: Format for argument generator_sources is incorrect, expected list, got:{type(generator_sources)}')
 
 class Config(BaseConfig):
     """
